IbanValidationResult class

The result returned by IbanValidator.validate.

Properties

cleanedIban String
The IBAN with spaces stripped and letters uppercased.
final
countryInfo IbanCountryInfo?
Metadata for the IBAN's country, when the country code is recognised.
final
error IbanValidationError?
The validation error, or null when isValid is true.
final
errorMessage String?
A human-readable description of error, or null when valid.
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Whether the IBAN passed all validation checks.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited